## Consolidation & Curation

*nshm-fault-sections* unifies the geologic fault data incorporated in all current NSHMs under a common data model.

#### Consolidation

* Export USGS PostgreSQL database tables:
  - `hazfaults_2008`
  - `hazfaults_2014`
* Union and export serialized UCERF3 California reference fault parameter database files:
  - `FM3_1.xml`
  - `FM3_2.xml`
* Extract fault section data from legacy hazard code input files for NSHMs outside the Conterminous U.S.

#### Naming Conventions

The consolidation and cleaning process imposed consistent IDs, names and naming conventions over the set of supported NSHM with an eye towards accommodating future growth. The process applied the following rules:

* Removed all model-specific modifiers (e.g. 'CFM 2011', 'rev')
* Removed all general geologic modifiers (e.g. 'fault zone', 'thrust', 'section')
* Renamed epistemic alternatives from, for example, `alt1` to `[1]`
* Updated all section modifiers to be lowercase (with a few exceptions), in parenthesis, and consistent with the following that are currently in use:
  - `north`, `east`, `south`, `west`
  - `center`, `middle`
  - `onshore`, `offshore`
  - `extension`¹, `extended`²
  - `connected`, `connector`
  - `multiple`
  - `seismicity`
  - `interface`

¹ _extension_, a discrete section off the end of another section  
² _extended_, a largely similar, longer version of a fault section; commonly represents an epistemic alternative  

#### Other Fault Section Modifiers

With respect to geographic modifiers, fault sections are often informally referred to by their relative locations (e.g. the South Cuyama fault). Over time, they take on this geographic reference as part of their name, but not in any formal way. As an example, and per the rules above, the South Cuyama fault has been renamed `Cuyama (south)`. We only retain a geographic descriptor if it is part of the formal place-name associated with a fault, for example: `North Tahoe`, `Western Toiyabe Range`, `Southern Whidbey Island`.

Many faults, especially very long ones such as the San Andreas or Wasatch, are composed of sections historically identified by a place name or names. Such place names are indicated in parenthesis after the fault name, for example, `Wasatch (Weber)`, and may be combined with other geographic modifiers, as needed.

When a fault section or its modifiers are composed of multiple fault or place names, they are separated with a hyphen surrounded by spaces (e.g. `Gravel Hills - Harper Lake`).

#### Epistemic Alternatives

The subsurface geometry of many faults is not well known. In some cases, epistemic alternatives have been considered in NSHMs and these are identified by numbers in square brackets, for example, `Santa Monica [1]`. No weights or model preferences are recorded in this repository; such values are only considered downstream when building NSHM logic trees.

#### Name Change Notes

* San Andreas (Mill Creek North Branch) changed to `Mill Creek (San Andreas, north branch)` and San Jacinto (Lytle Creek, connector) to  `Lytle Creek (San Jacinto, connector)` to distinguish them from the high slip rate sections, specifically, the 2008 southern California 'a-fault' sections.

#### Conversion Notes

Assembling the database revealed a variety of inconsistencies between source databases and hazard input files. For the sake of reproducibility of hazard calculations, the hazard input files were given precedence when resolving any ambiguities.

* XML input files derived rake attribute from the Fortran/Postgres `slip_sense`; 1 = strike slip (0 | ±180), 2 = reverse (90), 3 = normal (-90)); however, this led to all strike-slip faults having left-lateral rake, as well as obfuscating oblique slip on ruptures. Checked true rake values for consistency with `slip_sense` and hazard.
* California fault depths (2008) already include aseismicity factor (down-dip reduction in width)
* Very slight adjustments (that do not affect hazard) were made to fault section traces to give adjacent sections common endpoints and simplify fault section stitching (See READMEs of individual sections for details):
  - [`Santa Ynez (east)`](/../-/tree/maint-conus-2008/fault-sections/CA/Santa%20Ynez%20(east)), 2008
  - [`San Andreas (Carrizo)`](/../-/tree/maint-conus-2008/fault-sections/CA/San%20Andreas), 2008
  - [`San Andreas (Big Bend)`](/../-/tree/maint-conus-2008/fault-sections/CA/San%20Andreas), 2008
  - [`Elsinore (Julian)`](/../../../-/tree/maint-conus-2008/fault-sections/CA/Elsinore), 2008
* In some NSHMs, `[depth, width, dip]` are used to parameterize fault sections with the width commonly being an integer value, e.g. 14 km. When converted to `[upperDepth, lowerDepth, dip]`, the `lowerDepth` value is stored to three decimal places.
* The 2008 `Landers` section/rupture was mapped to `Camp Rock` for ID matching, however Landers is also composed of portions of the `Johnson Valley (north)`, `Kickapoo`, `Homestead Valley`, and `Emerson - Copper Mountain` sections.
* The 2008 `Ortigalita` section was mapped to `Ortigalita (south)` but it includes `Ortigalita (north)`.
* In some cases, for example, Cascadia, redundant rupture geometries were decomposed into individual fault sections.
* The following UCERF2 fault sections are missing from the 2008 database and hazard input files; each is present in the 2014 and later Conterminous U.S. editions of this repository:
  - `Channel Islands (ramp)`
  - `Earthquake Valley (north)`
  - `Earthquake Valley (south)`
  - `Holser [2]` (Holser has only 0.5 weight)
  - `Hosgri (extension)`
  - `Malibu Coast (extension) [1]`
  - `Malibu Coast (extension) [2]`
  - `Oak Ridge (offshore, extension)`
  - `San Gabriel (extension)`
  - `Santa Susana [2]` (Santa Susana has only 0.5 weight)
  - `Sierra Nevada (north)`
  - `White Wolf (extension)`
  - `Whittier [1]`  (Whittier [2] is northernmost Elsinore a-fault segment)
* The following UCERF2 fault sections are missing from the 2008 database, but are present in 2008 and later hazard input files:
  - `Hunter Mountain - Saline Valley`
  - `Newport - Inglewood [2]`
  - `Puente Hills`
  - `Santa Monica [2]`
* At some point after the release of the 2008 model, a transform that shifted traces by ~100m was applied to the 2008 database, the motivation for which is unclear. Note that traces as defined in this repository may not exactly match those in legacy databases.
