# Cascadia Subduction Zone (CSZ)

The Cascadia subduction zone model was updated in the Conterminous U.S. NSHM from 2008 to 2014,
remained the same in 2018, and was updated again in 2023. The update in 2023 further subdivided
the previous four north-to-south sections into ~50 km long sections to support addition of the
Goldfinger et al. (2017) model to the segemented branch of the Cascadia logic tree and an
alternative clustered model to the unsegmented branch.

## Section ID Groupings

The ID ranges of features used to define the geometry of current and past Casacadia models are
listed in the table below.

| Grouping              | ID Range       |
| ---------------------:|:-------------- |
| 2008 Sections         | `[3100..3103]` |
| 2014/2018 Sections    | `[3110..3142]` |
| 2014/2018 Ruptures    | `[3150..3149]` |
| 2023 Sections         | `[3200..3281]` |
| 2023 Ruptures         | `[3300..??]`   |

## Rupture Reference (2023)

The table below lists the IDs used for rupture sets on branches of the 2023
Casacadia logic tree.

| Sections             | 1    | 2    | 3    | 4    |                         |
|:-------------------- |:----:|:----:|:----:|:----:|:-----------------------:|
| Bottom               | 3200..3206 | 3207..3209 | 3210..3212 | 3213..3221 | |
| Middle               | 3230..3236 | 3237..3239 | 3240..3242 | 3243..3251 | |
| Top                  | 3260..3266 | 3267..3269 | 3270..3272 | 3273..3281 | |
| __Ruptures__         |      |      |      |      | [ Bottom, Middle, Top ] |
| Full, 1-2-3-4        | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |
| Segmented, 1         | ◆    |      |      |      | [ 3110, 3111, 3112 ]    |
| Segmented, 1-2       | ◆    | ◆    |      |      | [ 3150, 3151, 3152 ]    |
| Segmented, 1-2-3     | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Segmented, 4         |      |      |      | ◆    | [ 3140, 3141, 3142 ]    |
| Unsegmented, 1-2-3   | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Unsegmented, 1-2-3-4 | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |

TODO GEA17 models need to be added to the table above, which may warrant reformatting
to something more like the table below and/or names that more closely resemble the
names in the spreadsheet GEA12 Case A etc.

## Cluster Model (2023)

Table of clusters and relevant section ranges. The various combinations of ruptures below, each
composed of a minimum of 4 subsections, yields exactly one cluster section boundary between
sections 1-4 and 4-6.

Note on cluster- and rupture-IDs as implemented for bottom, middle, and top cluster
model files - within a `cluster-set.json` file, the cluster and rupture IDs are
incremental. Bottom IDs are 3300 to 3330, middle IDs are 3340 to 3370, and top
IDs are 3380 to 3410.

| Cluster | 2     | 3a    | 3b    | 4a      | 4b      | 5         |
|:-------:|:-----:|:-----:|:-----:|:-------:|:-------:|:---------:|
| Section | 11-11 | 8-6-8 | 7-8-7 | 6-6-5-5 | 5-5-6-6 | 4-5-4-5-4 |
| 4-9     | ◇     | ◆     | ◆     | ◇       | ◇       | ◆         |
| 4-8     | ◇     | ◆     | ◆     | ◇       | ◇       | ◆         |
| 4-7     | ◇     | ◆     | ◆     | ◇       | ◇       | ◆         |
| 4-6     | ◇     | ◆     | ◆     | ◇       | ◇       | ◆         |
| 4-5     | ◇     | ◆     | ◆     | ◇       | ◇       | ◇         |
| 4-4     | ◇     | ◆     | ◆     | ◆       | ◇       | ◇         |
| 4-3     | ◇     | ◆     | ◆     | ◆       | ◆       | ◇         |
| 4-2     | ◇     | ◆     | ◇     | ◆       | ◆       | ◇         |
| 4-1     | ◇     | ◇     | ◇     | ◆       | ◆       | ◇         |
| 3-3     | ◇     | ◇     | ◇     | ◆       | ◆       | ◆         |
| 3-2     | ◇     | ◇     | ◇     | ◇       | ◆       | ◆         |
| 3-1     | ◆     | ◇     | ◇     | ◇       | ◆       | ◆         |
| 2-3     | ◆     | ◇     | ◇     | ◇       | ◇       | ◆         |
| 2-2     | ◆     | ◇     | ◇     | ◇       | ◇       | ◇         |
| 2-1     | ◆     | ◆     | ◇     | ◇       | ◇       | ◇         |
| 1-7     | ◆     | ◆     | ◆     | ◇       | ◇       | ◇         |
| 1-6     | ◆     | ◆     | ◆     | ◆       | ◇       | ◇         |
| 1-5     | ◆     | ◆     | ◆     | ◆       | ◆       | ◇         |
| 1-4     | ◆     | ◆     | ◆     | ◆       | ◆       | ◆         |
| 1-3     | ◆     | ◆     | ◆     | ◆       | ◆       | ◆         |
| 1-2     | ◆     | ◆     | ◆     | ◆       | ◆       | ◆         |
| 1-1     | ◆     | ◆     | ◆     | ◆       | ◆       | ◆         |

## Rupture Reference (2014, 2018)

The table below lists the IDs used for rupture sets on different branches of the 2014 & 2018
Casacadia logic tree.

| Sections             | 1    | 2    | 3    | 4    |                         |
|:-------------------- |:----:|:----:|:----:|:----:|:-----------------------:|
| Bottom               | 3110 | 3120 | 3130 | 3140 |                         |
| Middle               | 3111 | 3121 | 3131 | 3141 |                         |
| Top                  | 3112 | 3122 | 3132 | 3142 |                         |
| __Ruptures__         |      |      |      |      | [ Bottom, Middle, Top ] |
| Full, 1-2-3-4        | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |
| Segmented, 1         | ◆    |      |      |      | [ 3110, 3111, 3112 ]    |
| Segmented, 1-2       | ◆    | ◆    |      |      | [ 3150, 3151, 3152 ]    |
| Segmented, 1-2-3     | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Segmented, 4         |      |      |      | ◆    | [ 3140, 3141, 3142 ]    |
| Unsegmented, 1-2-3   | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Unsegmented, 1-2-3-4 | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |

## Logic Tree Weight Adjustments

__bot:__ 1.856 instead of 1.8534  
__mid:__ 1.8528 instead of 1.8534  
__top:__ 1.856 instead of 1.8534  
